### Minimize F(x,y) with y>=-2
F(x,y)=6x^2 + y^3 + xy | ParametricSoln v0.2.1
by: Charlie Taylor | March 06, 2023

PRIOR TO MINIMIZE OPTIMIZATION
    ParametricSoln: F(x,y)=6x^2 + y^3 + xy

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             x            1           -2            2 X value
             y          0.2           -2            2 Y value

     Figure of Merit: Function Value (F) = 6.208  <== Minimize
    ============================================================================

AFTER MINIMIZE OPTIMIZATION
    ParametricSoln: F(x,y)=6x^2 + y^3 + xy

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             x     0.166669           -2            2 X value
             y           -2           -2            2 Y value

     Figure of Merit: Function Value (F) = -8.16667  <== Minimize
    ============================================================================

Design Variable Summary
Design Variables (nominal values)
Name | Value | Units | Description
x | 0.166669 |  | X value
y | -2 |  | Y value
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
F | -8.16667 |  | Function Value | --- | ---

Design Variable Summary
Design Variables (nominal values)
Name | Value | Units | Description
x | 0.166669 |  | X value
y | -2 |  | Y value
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
F | -8.16667 |  | Function Value | --- | ---

    Parametric Solutions
    parasol v0.2.1
    contact: C. Taylor, cet@appliedpython.com